# ou-tm351-py
Python installation package for TM351

Install from pypi as: `pip install ou-tm351-py`

This package is a dummy package that defines a comprehensive set of Python package dependencies required for studying the OU module [*Data management and analysis (TM351)*](https://www.open.ac.uk/courses/modules/tm351).

Note that the complete environment requires the installation of a variety of other services including PostgreSQL, MongoDB, OpenRefine.

A Docker container providing the complete environment can be found here: [`vce-jupyter-stacks/tm351-monolith`](https://github.com/OpenComputingLab/vce-jupyter-stacks/tree/main/tm351-monolith)
